@@ -27,16 +27,15 @@ pip install cloudcomponents.cdk-wordpress
 ## How to use
 
 ```python
-import { PublicHostedZone } from '@aws-cdk/aws-route53';
-import { Construct, RemovalPolicy, Stack, StackProps } from '@aws-cdk/core';
-
 import { Wordpress } from '@cloudcomponents/cdk-wordpress';
+import { RemovalPolicy, Stack, StackProps, aws_route53 } from 'aws-cdk-lib';
+import { Construct } from 'constructs';
 
 export class WordpressStack extends Stack {
   constructor(scope: Construct, id: string, props: StackProps) {
     super(scope, id, props);
 
-    const hostedZone = PublicHostedZone.fromLookup(this, 'HostedZone', {
+    const hostedZone = aws_route53.PublicHostedZone.fromLookup(this, 'HostedZone', {
       domainName: 'cloudcomponents.org',
     });
 
@@ -74,6 +73,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_backup
 import aws_cdk.aws_certificatemanager
 import aws_cdk.aws_cloudfront
@@ -82,17 +82,17 @@ import aws_cdk.aws_ecs
 import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_rds
 import aws_cdk.aws_route53
-import aws_cdk.core
+import constructs
 
 
 class Application(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-wordpress.Application",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         certificate: aws_cdk.aws_certificatemanager.ICertificate,
@@ -106,7 +106,7 @@ class Application(
         image: typing.Optional[aws_cdk.aws_ecs.ContainerImage] = None,
         log_driver: typing.Optional[aws_cdk.aws_ecs.LogDriver] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         secrets: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ecs.Secret]] = None,
         service_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -225,7 +225,7 @@ class ApplicationProps:
         image: typing.Optional[aws_cdk.aws_ecs.ContainerImage] = None,
         log_driver: typing.Optional[aws_cdk.aws_ecs.LogDriver] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         secrets: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ecs.Secret]] = None,
         service_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -334,9 +334,9 @@ class ApplicationProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
     def secrets(
@@ -363,13 +363,13 @@ class ApplicationProps:
 
 
 class Database(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-wordpress.Database",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
@@ -377,7 +377,7 @@ class Database(
         database_name: typing.Optional[builtins.str] = None,
         engine: typing.Optional[aws_cdk.aws_rds.IInstanceEngine] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''
         :param scope: -
@@ -444,7 +444,7 @@ class DatabaseProps:
         database_name: typing.Optional[builtins.str] = None,
         engine: typing.Optional[aws_cdk.aws_rds.IInstanceEngine] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''
         :param vpc: -
@@ -495,9 +495,9 @@ class DatabaseProps:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -512,13 +512,13 @@ class DatabaseProps:
 
 
 class Dns(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-wordpress.Dns",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         distribution: aws_cdk.aws_cloudfront.IDistribution,
@@ -598,18 +598,18 @@ class DnsProps:
 
 
 class EfsVolume(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-wordpress.EfsVolume",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
         name: typing.Optional[builtins.str] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''
         :param scope: -
@@ -656,7 +656,7 @@ class EfsVolumeProps:
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
         name: typing.Optional[builtins.str] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''
         :param vpc: -
@@ -683,9 +683,9 @@ class EfsVolumeProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -745,13 +745,13 @@ class StaticContentOffload:
 
 
 class Wordpress(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-wordpress.Wordpress",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         domain_name: builtins.str,
@@ -764,7 +764,7 @@ class Wordpress(
         log_driver: typing.Optional[aws_cdk.aws_ecs.LogDriver] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
         offload_static_content: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         secrets: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ecs.Secret]] = None,
         service_name: typing.Optional[builtins.str] = None,
         subject_alternative_names: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -869,7 +869,7 @@ class WordpressProps:
         log_driver: typing.Optional[aws_cdk.aws_ecs.LogDriver] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
         offload_static_content: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         secrets: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ecs.Secret]] = None,
         service_name: typing.Optional[builtins.str] = None,
         subject_alternative_names: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -982,9 +982,9 @@ class WordpressProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
     def secrets(
